==> plotly-3.3.0-py2.py3-none-any.whl: plotly/validators/pie/__init__.py <==
from ._visible import VisibleValidator
from ._valuessrc import ValuessrcValidator
from ._values import ValuesValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._textpositionsrc import TextpositionsrcValidator
from ._textposition import TextpositionValidator
from ._textinfo import TextinfoValidator
from ._textfont import TextfontValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._sort import SortValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._scalegroup import ScalegroupValidator
from ._rotation import RotationValidator
from ._pullsrc import PullsrcValidator
from ._pull import PullValidator
from ._outsidetextfont import OutsidetextfontValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._labelssrc import LabelssrcValidator
from ._labels import LabelsValidator
from ._label0 import Label0Validator
from ._insidetextfont import InsidetextfontValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._hole import HoleValidator
from ._domain import DomainValidator
from ._dlabel import DlabelValidator
from ._direction import DirectionValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator

==> plotly-3.4.1rc1-py2.py3-none-any.whl: plotly/validators/pie/__init__.py <==
from ._visible import VisibleValidator
from ._valuessrc import ValuessrcValidator
from ._values import ValuesValidator
from ._uid import UidValidator
from ._titleposition import TitlepositionValidator
from ._titlefont import TitlefontValidator
from ._title import TitleValidator
from ._textsrc import TextsrcValidator
from ._textpositionsrc import TextpositionsrcValidator
from ._textposition import TextpositionValidator
from ._textinfo import TextinfoValidator
from ._textfont import TextfontValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._sort import SortValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._scalegroup import ScalegroupValidator
from ._rotation import RotationValidator
from ._pullsrc import PullsrcValidator
from ._pull import PullValidator
from ._outsidetextfont import OutsidetextfontValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._labelssrc import LabelssrcValidator
from ._labels import LabelsValidator
from ._label0 import Label0Validator
from ._insidetextfont import InsidetextfontValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._hole import HoleValidator
from ._domain import DomainValidator
from ._dlabel import DlabelValidator
from ._direction import DirectionValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
